@@ -673,12 +673,15 @@ apt_worker_install_check (int state, const char *package,
 }
 
 void
-apt_worker_install_package (int state, const char *package, bool updating,
+apt_worker_install_package (int state, const char *package,
+			    const char *alt_download_root, bool updating,
 			    apt_worker_callback *callback, void *data)
 {
   request.reset ();
   request.encode_string (package);
-  
+
+  request.encode_string (alt_download_root);
+
   char *http_proxy = get_http_proxy ();
   request.encode_string (http_proxy);
   g_free (http_proxy);
