@@ -349,6 +349,7 @@ static GList *upgradeable_packages = NULL;
 static GList *installed_packages = NULL;
 static GList *search_result_packages = NULL;
 static GList *temp_packages = NULL;
+static gboolean package_list_ready = false;
 
 static char *cur_section_name;
 
@@ -907,6 +908,12 @@ get_package_list_reply (int cmd, apt_proto_decoder *dec, void *data)
     default:
       delete c;
     }
+
+  /* At least the first package list load is done */
+  if (!package_list_ready)
+    {
+      package_list_ready = true;
+    }
 }
 
 void
@@ -1359,8 +1366,7 @@ rpc_with_network (bool success, void *data)
       
       c->result_code = rescode_failure;
       c->keep_going = false;
-      annoy_user (_("No network connection"),
-		  rpc_done, c);
+      rpc_done (c);
     }
 }
 
@@ -1427,13 +1433,22 @@ rpc_show_error_report (void *data)
   if (c->result_code == rescode_partial_success)
     {
       if (c->continued)
-	dialog = hildon_note_new_confirmation_add_buttons 
-	  (NULL,
-	   _("ai_ni_update_partly_successful"),
-	   _("ai_bd_continue"), GTK_RESPONSE_OK,
-	   _("ai_ni_bd_details"), 1,
-	   _("ai_bd_notice_cancel"), GTK_RESPONSE_CANCEL,
-	   NULL);
+	{
+	  gchar *msg =
+	    g_strdup_printf ("%s\n%s",
+			     _("ai_ni_update_partly_successful"),
+			     _("ai_ni_continue_install"));
+
+	  dialog = hildon_note_new_confirmation_add_buttons 
+	    (NULL,
+	     msg,
+	     _("ai_bd_ok"), GTK_RESPONSE_OK,
+	     _("ai_ni_bd_details"), 1,
+	     _("ai_bd_notice_cancel"), GTK_RESPONSE_CANCEL,
+	     NULL);
+
+	  g_free (msg);
+	}
       else
 	dialog = hildon_note_new_confirmation_add_buttons 
 	  (NULL,
@@ -1788,7 +1803,13 @@ check_catalogues_reply (xexp *catalogues, void *data)
 static void
 check_catalogues ()
 {
-  get_catalogues (check_catalogues_reply, NULL);
+  if (package_list_ready)
+    {
+      /* Avoid to call get_catalogues if packages_list it not ready,
+	 because that function finally calls to get_catalogues too,
+	 and they could conflict during start up */
+      get_catalogues (check_catalogues_reply, NULL);
+    }
 }
 
 GtkWidget *
@@ -2490,7 +2511,19 @@ install_from_file_flow (const char *filename)
       if (filename == NULL)
 	show_deb_file_chooser (iff_with_filename, NULL);
       else
-	iff_with_filename (g_strdup (filename), NULL);
+	{
+	  /* Try to convert filename to GnomeVFS uri */
+	  char *fileuri = 
+	    gnome_vfs_get_uri_from_local_path (filename);
+
+	  /* If there's an error then user filename as is */
+	  if (fileuri == NULL)
+	    {
+	      fileuri = g_strdup (filename);
+	    }
+
+	  iff_with_filename (fileuri, NULL);
+	}
     }
 }
 
