@@ -33,6 +33,7 @@
 #include "settings.h"
 #include "repo.h"
 #include "search.h"
+#include "apt-worker-client.h"
 
 #define _(x) gettext (x)
 
@@ -58,6 +59,22 @@ add_item (GtkMenu *menu, const gchar *label, const gchar *insens,
   return item;
 }
 
+static GtkWidget *
+add_item_with_shortcut (GtkMenu *menu, const gchar *label,
+			const gchar *insens,
+			void (*func)(),
+			GtkAccelGroup *accel_group, guint key)
+{
+  GtkWidget *item = add_item (menu, label, insens, func);
+
+  gtk_widget_add_accelerator (item, "activate",
+			      accel_group,
+			      key, GDK_CONTROL_MASK,
+			      GTK_ACCEL_VISIBLE);
+
+  return item;
+}
+
 static GtkWidget *
 add_check (GtkMenu *menu, const gchar *label, void (*func)())
 {
@@ -85,10 +102,11 @@ add_menu (GtkMenu *menu, const gchar *label)
   return GTK_MENU (sub);
 }
 
-static void
+void
 menu_close ()
 {
-  exit (0);
+  hide_main_window ();
+  maybe_exit ();
 }
 
 static GtkWidget *details_menu_item = NULL;
@@ -165,18 +183,6 @@ fullscreen_toolbar_activated (GtkWidget *item)
   set_toolbar_visibility (true, active);
 }
 
-static void
-call_refresh_package_cache ()
-{
-  refresh_package_cache (APTSTATE_DEFAULT, true);
-}
-
-static void
-call_restore_packages ()
-{
-  restore_packages_flow ();
-}
-
 static void
 call_install_from_file ()
 {
@@ -184,12 +190,22 @@ call_install_from_file ()
 }
 
 void
-create_menu (GtkMenu *main)
+create_menu (HildonWindow *window)
 {
+  GtkWidget *item;
+  GtkWidget *restore_item;
+  GtkAccelGroup *accel_group;
+  gchar *restore_filename;
+
+  accel_group = gtk_accel_group_new ();
+  gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
+
+  GtkMenu *main = GTK_MENU (gtk_menu_new ());
+  hildon_window_set_menu (window, GTK_MENU (main));
+
   GtkMenu *packages = add_menu (main, _("ai_me_package"));
   GtkMenu *view = add_menu (main, _("ai_me_view"));
   GtkMenu *tools = add_menu (main, _("ai_me_tools"));
-  GtkWidget *item;
 
   operation_menu_item = add_item (packages, "", NULL, do_current_operation);
   g_signal_connect (operation_menu_item, "insensitive_press",
@@ -205,7 +221,7 @@ create_menu (GtkMenu *main)
 
   add_item (view,
 	    _("ai_me_view_sort"), NULL,
-	    show_sort_settings_dialog);
+	    show_sort_settings_dialog_flow);
   add_sep (view);
   fullscreen_item = add_check (view, _("ai_me_view_fullscreen"), NULL);
   g_signal_connect (fullscreen_item, "activate",
@@ -226,32 +242,41 @@ create_menu (GtkMenu *main)
   g_signal_connect (item, "activate",
 		    G_CALLBACK (fullscreen_toolbar_activated), NULL);
 
-  add_item (tools,
-	    _("ai_me_tools_restore"), NULL,
-	    call_restore_packages);
+  /* get a reference to the widget to set sensitiveness as needed */
+  restore_item = add_item (tools,
+			   _("ai_me_tools_restore"), 
+			   _("ai_ib_nothing_restore"),
+			   restore_packages_flow);
   add_item (tools,
 	    _("ai_me_tools_refresh"), NULL,
-	    call_refresh_package_cache);
+	    refresh_package_cache_flow);
   add_item (tools,
 	    _("ai_me_tools_settings"), NULL,
-	    show_settings_dialog);
+	    show_settings_dialog_flow);
   add_item (tools,
 	    _("ai_me_tools_repository"), NULL,
-	    show_repo_dialog);
+	    show_catalogue_dialog_flow);
   search_menu_item =
     add_item (tools,
 	      _("ai_me_tools_search"), _("ai_ib_unable_search"),
-	      show_search_dialog);
+	      show_search_dialog_flow);
   add_item (tools,
 	    _("ai_me_tools_log"), NULL,
-	    show_log);
+	    show_log_dialog_flow);
   add_item (tools,
 	    _("ai_me_tools_help"), NULL,
 	    show_help);
 
-  add_item (main,
-	    _("ai_me_close"), NULL,
-	    menu_close);
+  add_item_with_shortcut (main,
+			  _("ai_me_close"), NULL,
+			  menu_close,
+			  accel_group, 'q');
+
+  /* Set sensitiveness for restore_packages menu item */
+  restore_filename = g_strdup_printf ("%s/%s", 
+				      g_get_home_dir (), RESTORE_BACKUP_FILENAME);
+  gtk_widget_set_sensitive (restore_item, (xexp_read_file (restore_filename) != NULL));
+  g_free (restore_filename);
 
   gtk_widget_show_all (GTK_WIDGET (main));
 }
