@@ -1,3 +1,4 @@
+
 /*
  * This file is part of the hildon-application-manager.
  *
@@ -43,29 +44,39 @@
 
 #define HAM_BACKUP_RESPONSE 1
 
+/* MMC mountpoints */
+#define INTERNAL_MMC_MOUNTPOINT "/media/mmc2"
+#define REMOVABLE_MMC_MOUNTPOINT "/media/mmc1"
+
 /* Common utilities
  */
 
 static char *
-result_code_to_message (apt_proto_result_code result_code, bool upgrading)
+result_code_to_message (package_info *pi, 
+			apt_proto_result_code result_code)
 {
-  const char *msg = NULL;
+  char *msg = NULL;
+  bool upgrading = (pi->installed_version != NULL);
 
   if (result_code == rescode_download_failed)
-    msg = _("ai_ni_error_download_failed");
+    msg = g_strdup_printf (_("ai_ni_error_download_failed"),
+			   pi->get_display_name (false));
   else if (result_code == rescode_packages_not_found)
-    msg = _("ai_ni_error_download_missing");
+    msg = g_strdup_printf (_("ai_ni_error_download_missing"),
+			   pi->get_display_name (false));
   else if (result_code == rescode_package_corrupted)
     {
       if (upgrading)
-	msg = _("ai_ni_error_update_corrupted");
+	msg = g_strdup_printf (_("ai_ni_error_update_corrupted"),
+			       pi->get_display_name (true));
       else
-	msg = _("ai_ni_error_install_corrupted");
+	msg = g_strdup_printf (_("ai_ni_error_install_corrupted"),
+			       pi->get_display_name (false));
     }
   else if (result_code == rescode_out_of_space)
-    msg = dgettext ("hildon-common-strings", "sfil_ni_not_enough_memory");
+    msg = g_strdup (dgettext ("hildon-common-strings", "sfil_ni_not_enough_memory"));
 
-  return g_strdup (msg);
+  return msg;
 }
 
 void
@@ -74,8 +85,7 @@ installable_status_to_message (package_info *pi,
 {
   if (pi->info.installable_status == status_missing)
     {
-      msg = g_strdup_printf ("%s\n%s",
-			     (pi->installed_version
+      msg = g_strdup_printf ((pi->installed_version
 			      ? _("ai_ni_error_update_missing")
 			      : _("ai_ni_error_install_missing")),
 			     pi->get_display_name (false));
@@ -83,8 +93,7 @@ installable_status_to_message (package_info *pi,
     }
   else if (pi->info.installable_status == status_conflicting)
     {
-      msg = g_strdup_printf ("%s\n%s",
-			     (pi->installed_version
+      msg = g_strdup_printf ((pi->installed_version
 			      ? _("ai_ni_error_update_conflict")
 			      : _("ai_ni_error_install_conflict")),
 			     pi->get_display_name (false));
@@ -92,8 +101,7 @@ installable_status_to_message (package_info *pi,
     }
   else if (pi->info.installable_status == status_corrupted)
     {
-      msg = g_strdup_printf ("%s\n%s",
-			     (pi->installed_version
+      msg = g_strdup_printf ((pi->installed_version
 			      ? _("ai_ni_error_update_corrupted")
 			      : _("ai_ni_error_install_corrupted")),
 			     pi->get_display_name (false));
@@ -101,8 +109,7 @@ installable_status_to_message (package_info *pi,
     }
   else if (pi->info.installable_status == status_incompatible)
     {
-      msg = g_strdup_printf ("%s\n%s",
-			     (pi->installed_version
+      msg = g_strdup_printf ((pi->installed_version
 			      ? _("ai_ni_error_update_incompatible")
 			      : _("ai_ni_error_install_incompatible")),
 			     pi->get_display_name (false));
@@ -110,15 +117,13 @@ installable_status_to_message (package_info *pi,
     }
   else if (pi->info.installable_status == status_incompatible_current)
     {
-      msg = g_strdup_printf ("%s\n%s",
-			     _("ai_ni_error_n770package_incompatible"),
+      msg = g_strdup_printf (_("ai_ni_error_n770package_incompatible"),
 			     pi->get_display_name (false));
       with_details = false;
     }
   else if (pi->info.installable_status == status_not_found)
     {
-      msg = g_strdup_printf ("%s\n%s",
-			     _("ai_ni_error_download_missing"),
+      msg = g_strdup_printf (_("ai_ni_error_download_missing"),
 			     pi->get_display_name (false));
       with_details = false;
     }
@@ -207,6 +212,7 @@ struct ip_clos {
   // per installation iteration
   int flags;
   int64_t free_space;       // the required free storage space in bytes
+  char *alt_download_root;  // Alternative download root filesystem.
   GSList *upgrade_names;    // the packages and versions that we are going
   GSList *upgrade_versions; // to upgrade to.
 
@@ -285,6 +291,7 @@ install_packages (GList *packages,
   c->all_packages = packages;
   c->cont = cont;
   c->data = data;
+  c->alt_download_root = NULL;
   c->upgrade_names = NULL;
   c->upgrade_versions = NULL;
   c->n_successful = 0;
@@ -549,10 +556,19 @@ ip_check_cert_reply (int cmd, apt_proto_decoder *dec, void *data)
   if (some_domains_violated)
     {
       if (red_pill_mode)
-	ask_custom (_("ai_ni_error_broken_path"),
-		    _("ai_bd_continue"),
-		    _("ai_bd_cancel"),
-		    ip_legalese_response, c);
+	{
+	  gchar *msg =
+	    g_strdup_printf ("%s\n%s",
+			     _("ai_ni_error_broken_path"),
+			     _("ai_ni_continue_install"));
+
+	  ask_custom (msg,
+		      _("ai_bd_ok"),
+		      _("ai_bd_cancel"),
+		      ip_legalese_response, c);
+
+	  g_free (msg);
+	}
       else
 	annoy_user (_("ai_ni_error_broken_path"),
 		    ip_end, c);
@@ -676,8 +692,50 @@ ip_install_with_info (package_info *pi, void *data, bool changed)
 	annoy_user_with_errno (errno, "get_free_space",
 			       ip_end, c);
 
-      if (pi->info.required_free_space + pi->info.download_size >= free_space)
+      bool keep_installing = false;
+      if (pi->info.required_free_space < free_space)
 	{
+	  /* Check MMCs first if download to mmc option is enabled */
+	  if (download_packages_to_mmc)
+	    {
+	      if (volume_path_is_mounted (INTERNAL_MMC_MOUNTPOINT) &&
+		  pi->info.download_size < get_free_space_at_path (INTERNAL_MMC_MOUNTPOINT))
+		{
+		  c->alt_download_root = INTERNAL_MMC_MOUNTPOINT;
+		  keep_installing = true;
+		}
+	      else if (volume_path_is_mounted (REMOVABLE_MMC_MOUNTPOINT) &&
+		       pi->info.download_size < get_free_space_at_path (REMOVABLE_MMC_MOUNTPOINT))
+		{
+		  c->alt_download_root = REMOVABLE_MMC_MOUNTPOINT;
+		  keep_installing = true;
+		}
+	    }
+
+	  /* Check internal flash if it's still needed */
+	  if (!keep_installing &&
+	      (free_space > (pi->info.required_free_space + pi->info.download_size)))
+	    {
+	      keep_installing = true;
+	    }
+	}
+
+      /* If there's enough space somewhere, proceed with installation */
+      if (keep_installing)
+	{
+	  if (pi->info.install_flags & pkgflag_close_apps)
+	    {
+	      ask_yes_no (_("ai_nc_close_apps"), ip_close_apps, c);
+	    }
+	  else
+	    {
+	      apt_worker_install_check (c->state, pi->name,
+					ip_check_upgrade_reply, c);
+	    }
+	}
+      else
+	{
+	  /* Not enough free space */
 	  char free_string[20];
 	  char required_string[20];
 	  size_string_detailed (free_string, 20, free_space);
@@ -685,20 +743,11 @@ ip_install_with_info (package_info *pi, void *data, bool changed)
 				pi->info.required_free_space
 				+ pi->info.download_size);
 
-	  char *msg = g_strdup_printf ("Not enough storage\n%s < %s",
+	  char *msg = g_strdup_printf ("%s\n%s < %s",
+				       dgettext ("hildon-common-strings", "sfil_ni_not_enough_memory"),
 				       free_string, required_string);
-
 	  ip_abort_cur (c, msg, false);
 	}
-      else if (pi->info.install_flags & pkgflag_close_apps)
-	{
-	  ask_yes_no (_("ai_nc_close_apps"), ip_close_apps, c);
-	}
-      else
-	{
-	  apt_worker_install_check (c->state, pi->name,
-				    ip_check_upgrade_reply, c);
-	}
     }
   else
     ip_abort_cur_with_status_details (c);
@@ -831,6 +880,7 @@ ip_install_cur (void *data)
 
   set_log_start ();
   apt_worker_install_package (c->state, pi->name,
+			      c->alt_download_root,
 			      pi->installed_version != NULL,
 			      ip_install_cur_reply, c);
 }
@@ -870,8 +920,7 @@ ip_install_cur_reply (int cmd, apt_proto_decoder *dec, void *data)
 	{
 	  result_code = scan_log_for_result_code (result_code);
 	  char *msg =
-	    result_code_to_message (result_code,
-				    pi->installed_version != NULL);
+	    result_code_to_message (pi, result_code);
 	  if (msg == NULL)
 	    msg = g_strdup_printf ((pi->installed_version != NULL
 				    ? _("ai_ni_error_update_failed")
@@ -907,7 +956,7 @@ ip_suggest_backup (ip_clos *c)
 {
   GtkWidget *dialog = NULL;
   gint result = G_MAXINT; 
-  gboolean keep_asking = TRUE;
+  gboolean keep_asking = FALSE;
   
   /* Show custom dialog if suggest_backup flag is present */
   dialog = gtk_dialog_new_with_buttons
@@ -929,29 +978,18 @@ ip_suggest_backup (ip_clos *c)
 
   /* Use gtk_dialog_run to block execution while the dialog is
      not closed */
-  while (keep_asking)
+  do
     {
       char *argv[] = {"/usr/bin/osso-backup", NULL};
       result = gtk_dialog_run (GTK_DIALOG (dialog));
-      switch (result)
+
+      keep_asking = FALSE;
+      if (result == HAM_BACKUP_RESPONSE)
 	{
-	case GTK_RESPONSE_OK:
-	  /* Do nothing, just continue with the process */	  
-	  keep_asking = FALSE;
-	  break;
-	    
-	case GTK_RESPONSE_CANCEL:
-	  keep_asking = FALSE;
-	  break;
-	    
-	case HAM_BACKUP_RESPONSE:
  	  run_cmd (argv, ip_suggest_backup_cmd_done, NULL);
-	  break;
-	    
-	default:
-	  g_assert_not_reached ();
+	  keep_asking = TRUE;
 	}
-    }
+    } while (keep_asking);
 
   pop_dialog (GTK_WIDGET (dialog));
   gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -978,8 +1016,7 @@ ip_close_apps (bool res, void *data)
     {
       close_apps ();
 
-      /* Make sure we are done before killing apps, also makes things look
-       * smoother. */
+      /* Make sure we are done before continuing */
       while (gtk_events_pending ())
 	gtk_main_iteration ();
 
@@ -1008,19 +1045,33 @@ ip_abort_cur (ip_clos *c, const char *msg, bool with_details)
   bool is_last = (c->cur->next == NULL);
 
   GtkWidget *dialog;
+  gchar *final_msg = NULL;
 
   stop_entertaining_user ();
   c->entertaining = false;
 
   // XXX - get the button texts correct, etc.
 
+  /* Build the final string to be shown as the dialog main text */
+  if (!is_last)
+    {
+      final_msg =
+	g_strdup_printf ("%s\n%s", 
+			 msg,
+			 _("ai_ni_continue_install"));
+    }
+  else
+    {
+      final_msg = g_strdup (msg);
+    }
+
   if (with_details)
     {
       if (is_last)
 	{
 	  dialog = hildon_note_new_confirmation_add_buttons 
 	    (NULL,
-	     msg,
+	     final_msg,
 	     _("ai_ni_bd_details"), 1,
 	     _("ai_ni_bd_close"), GTK_RESPONSE_CANCEL,
 	     NULL);
@@ -1029,8 +1080,8 @@ ip_abort_cur (ip_clos *c, const char *msg, bool with_details)
 	{
 	  dialog = hildon_note_new_confirmation_add_buttons 
 	    (NULL,
-	     msg,
-	     _("ai_bd_continue"), GTK_RESPONSE_OK,
+	     final_msg,
+	     _("ai_bd_ok"), GTK_RESPONSE_OK,
 	     _("ai_ni_bd_details"), 1,
 	     _("ai_bd_notice_cancel"), GTK_RESPONSE_CANCEL,
 	     NULL);
@@ -1042,7 +1093,7 @@ ip_abort_cur (ip_clos *c, const char *msg, bool with_details)
 	{
 	  dialog = hildon_note_new_confirmation_add_buttons 
 	    (NULL,
-	     msg,
+	     final_msg,
 	     _("ai_ni_bd_close"), GTK_RESPONSE_CANCEL,
 	     NULL);
 	}
@@ -1050,13 +1101,15 @@ ip_abort_cur (ip_clos *c, const char *msg, bool with_details)
 	{
 	  dialog = hildon_note_new_confirmation_add_buttons 
 	    (NULL,
-	     msg,
-	     _("ai_bd_continue"), GTK_RESPONSE_OK,
+	     final_msg,
+	     _("ai_bd_ok"), GTK_RESPONSE_OK,
 	     _("ai_bd_notice_cancel"), GTK_RESPONSE_CANCEL,
 	     NULL);
 	}
     }
 
+  g_free (final_msg);
+
   push_dialog (dialog);
 
   g_signal_connect (dialog, "response",
@@ -1293,8 +1346,12 @@ up_remove (up_clos *c)
       if (c->pi->info.removable_status == status_system_update_unremovable)
 	annoy_user (_("ai_ni_unable_to_uninstall_system_update"), up_end, c);
       else if (c->pi->info.removable_status == status_needed)
-	annoy_user_with_details (_("ai_ni_error_uninstall_packagesneeded"),
-				 c->pi, remove_details, up_end, c);
+	{
+	  char *str = g_strdup_printf (_("ai_ni_error_uninstall_packagesneeded"),
+				       c->pi->get_display_name (true));
+	  annoy_user_with_details (str, c->pi, remove_details, up_end, c);
+	  g_free (str);
+	}
       else
 	{
 	  char *str = g_strdup_printf (_("ai_ni_error_uninstallation_failed"),
@@ -1596,8 +1653,7 @@ if_install_reply (int cmd, apt_proto_decoder *dec, void *data)
       apt_proto_result_code result_code = rescode_failure;
       result_code = scan_log_for_result_code (result_code);
 
-      char *msg = result_code_to_message (result_code, 
-					  c->pi->installed_version != NULL);
+      char *msg = result_code_to_message (c->pi, result_code);
       if (msg == NULL)
 	msg = g_strdup_printf (c->pi->installed_version
 			       ? _("ai_ni_error_update_failed")
